@@ -10,7 +10,7 @@ use Data::Dumper;
 use Module::Starter;
 $Data::Dumper::Deparse = 1;
 
-our $VERSION = '0.02';
+our $VERSION = '0.03';
 our %CLASS;
 
 sub dist {
@@ -227,10 +227,15 @@ sub _build_subs {
 	my @codes;
 	delete $class->{SUBS}{CURRENT};
 	for my $sub (sort keys %{$class->{SUBS}}) {
-		my $code = Dumper $class->{SUBS}{$sub}{CODE};
-		$code =~ s/\$VAR1 = sub //;
-		$code =~ s/};$/}/;
-		$code = sprintf "sub %s %s", $sub, $code;
+		my $code;
+		if ($class->{SUBS}{$sub}{CODE}) {
+			$code = Dumper $class->{SUBS}{$sub}{CODE};
+			$code =~ s/\$VAR1 = sub //;
+			$code =~ s/};$/}/;
+			$code = sprintf "sub %s %s", $sub, $code;
+		} else {
+			$code = sprintf "sub %s {\n\n\n}", $sub;
+		}
 		push @codes, $code;
 	}
 	return join "\n", @codes;
@@ -379,7 +384,7 @@ Module::Generate - Assisting with module generation.
 
 =head1 VERSION
 
-Version 0.02
+Version 0.03
 
 =cut
 
@@ -413,6 +418,26 @@ Version 0.02
 				->example('$plane->altitude(100, 100)')
 		->generate;
 
+	...
+
+	Module::Generate->dist('Holiday')
+		->author('LNATION')
+		->email('email@lnation.org')
+		->version('0.01')
+		->class('Feed::Data')
+			->use('Data::LnArray')
+			->our('$holiday')
+			->begin(sub {
+				$holiday = Data::LnArray->new;
+			})
+			->sub('parse')
+			->sub('write')
+			->sub('render')
+			->sub('generate')
+			->sub('_raw')
+			->sub('_text')
+			->sub('_json')
+		->generate;
 
 =head1 SUBROUTINES/METHODS
 
